@@ -3,7 +3,6 @@ import json
 from awesomeTaskPy.log.loger import loger
 import sys
 contextObj=None
-TASKINFOREPLACE="-|&|-"
 class Singleton(object):
     def __init__(self, cls):
         self._cls = cls
@@ -35,10 +34,12 @@ def initContext():
     global contextObj
     if contextObj!=None:
         return contextObj
-    params='{"taskId":"test"}'
+    params=1
     if len(sys.argv)>=2:
-        params=sys.argv[1]
+        taskId=sys.argv[1]
         global TASKINFOREPLACE
-        params=params.replace(TASKINFOREPLACE,'"')
+        inputPath = sys.path[0] + "/input" + "/" + taskId + "/input.log"
+        data=open(inputPath,encoding='utf -8').read()
+        params=json.loads(data)
     taskInfo=json.loads(params)
     contextObj=context(taskInfo)
